@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2019 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -35,7 +35,7 @@ class OGRSpatialReference;
 extern SRS srs;
 extern bool debug;
 
-std::unique_ptr<OGRPolygon> CoastlinePolygons::create_rectangular_polygon(double x1, double y1, double x2, double y2, double expand) const {
+static std::unique_ptr<OGRPolygon> create_rectangular_polygon(double x1, double y1, double x2, double y2, double expand) {
     OGREnvelope e;
 
     e.MinX = x1 - expand;
@@ -60,6 +60,31 @@ std::unique_ptr<OGRPolygon> CoastlinePolygons::create_rectangular_polygon(double
     return polygon;
 }
 
+static bool add_segment_to_line(OGRLineString* line, OGRPoint* point1, OGRPoint* point2) {
+    // segments along southern edge of the map are not added to line output
+    if (point1->getY() < srs.min_y() && point2->getY() < srs.min_y()) {
+        if (debug) {
+            std::cerr << "Suppressing segment (" << point1->getX() << " " << point1->getY() << ", " << point2->getX() << " " << point2->getY() << ") near southern edge of map.\n";
+        }
+        return false;
+    }
+
+    // segments along antimeridian are not added to line output
+    if ((point1->getX() > srs.max_x() && point2->getX() > srs.max_x()) ||
+        (point1->getX() < srs.min_x() && point2->getX() < srs.min_x())) {
+        if (debug) {
+            std::cerr << "Suppressing segment (" << point1->getX() << " " << point1->getY() << ", " << point2->getX() << " " << point2->getY() << ") near antimeridian.\n";
+        }
+        return false;
+    }
+
+    if (line->getNumPoints() == 0) {
+        line->addPoint(point1);
+    }
+    line->addPoint(point2);
+    return true;
+}
+
 unsigned int CoastlinePolygons::fix_direction() {
     unsigned int warnings = 0;
 
@@ -218,31 +243,6 @@ void CoastlinePolygons::output_land_polygons(bool make_copy) {
     }
 }
 
-bool CoastlinePolygons::add_segment_to_line(OGRLineString* line, OGRPoint* point1, OGRPoint* point2) const {
-    // segments along southern edge of the map are not added to line output
-    if (point1->getY() < srs.min_y() && point2->getY() < srs.min_y()) {
-        if (debug) {
-            std::cerr << "Suppressing segment (" << point1->getX() << " " << point1->getY() << ", " << point2->getX() << " " << point2->getY() << ") near southern edge of map.\n";
-        }
-        return false;
-    }
-
-    // segments along antimeridian are not added to line output
-    if ((point1->getX() > srs.max_x() && point2->getX() > srs.max_x()) ||
-        (point1->getX() < srs.min_x() && point2->getX() < srs.min_x())) {
-        if (debug) {
-            std::cerr << "Suppressing segment (" << point1->getX() << " " << point1->getY() << ", " << point2->getX() << " " << point2->getY() << ") near antimeridian.\n";
-        }
-        return false;
-    }
-
-    if (line->getNumPoints() == 0) {
-        line->addPoint(point1);
-    }
-    line->addPoint(point2);
-    return true;
-}
-
 void CoastlinePolygons::add_line_to_output(std::unique_ptr<OGRLineString> line, OGRSpatialReference* srs) const {
     line->setCoordinateDimension(2);
     line->assignSpatialReference(srs);
@@ -305,11 +305,13 @@ static bool antarctica_bogus(const OGRGeometry* geom) noexcept {
     return env_east.Contains(envelope) || env_west.Contains(envelope);
 }
 
-void CoastlinePolygons::split_bbox(OGREnvelope e, polygon_vector_type&& v) {
-//    std::cerr << "envelope = (" << e.MinX << ", " << e.MinY << "), (" << e.MaxX << ", " << e.MaxY << ") v.size()=" << v.size() << "\n";
+void CoastlinePolygons::split_bbox(const OGREnvelope& envelope, polygon_vector_type&& v) {
+//    std::cerr << "envelope = (" << envelope.MinX << ", " << envelope.MinY
+//              << "), (" << envelope.MaxX << ", " << envelope.MaxY
+//              << ") v.size()=" << v.size() << "\n";
     if (v.size() < 100) {
         try {
-            std::unique_ptr<OGRGeometry> geom{create_rectangular_polygon(e.MinX, e.MinY, e.MaxX, e.MaxY, m_expand)};
+            std::unique_ptr<OGRGeometry> geom{create_rectangular_polygon(envelope.MinX, envelope.MinY, envelope.MaxX, envelope.MaxY, m_expand)};
             assert(geom->getSpatialReference() != nullptr);
             for (const auto& polygon : v) {
                 std::unique_ptr<OGRGeometry> diff{geom->Difference(polygon.get())};
@@ -342,7 +344,17 @@ void CoastlinePolygons::split_bbox(OGREnvelope e, polygon_vector_type&& v) {
                         // XXX
                         break;
                     default:
-                        std::cerr << "IGNORING envelope = (" << e.MinX << ", " << e.MinY << "), (" << e.MaxX << ", " << e.MaxY << ") type=" << geom->getGeometryName() << "\n";
+                        std::cerr << "IGNORING envelope = ("
+                                  << envelope.MinX
+                                  << ", "
+                                  << envelope.MinY
+                                  << "), ("
+                                  << envelope.MaxX
+                                  << ", "
+                                  << envelope.MaxY
+                                  << ") type="
+                                  << geom->getGeometryName()
+                                  << "\n";
                         // ignore XXX
                         break;
                 }
@@ -355,33 +367,33 @@ void CoastlinePolygons::split_bbox(OGREnvelope e, polygon_vector_type&& v) {
         OGREnvelope e1;
         OGREnvelope e2;
 
-        if (e.MaxX - e.MinX < e.MaxY - e.MinY) {
+        if (envelope.MaxX - envelope.MinX < envelope.MaxY - envelope.MinY) {
             // split vertically
-            const double MidY = (e.MaxY + e.MinY) / 2;
+            const double MidY = (envelope.MaxY + envelope.MinY) / 2;
 
-            e1.MinX = e.MinX;
-            e1.MinY = e.MinY;
-            e1.MaxX = e.MaxX;
+            e1.MinX = envelope.MinX;
+            e1.MinY = envelope.MinY;
+            e1.MaxX = envelope.MaxX;
             e1.MaxY = MidY;
 
-            e2.MinX = e.MinX;
+            e2.MinX = envelope.MinX;
             e2.MinY = MidY;
-            e2.MaxX = e.MaxX;
-            e2.MaxY = e.MaxY;
+            e2.MaxX = envelope.MaxX;
+            e2.MaxY = envelope.MaxY;
 
         } else {
             // split horizontally
-            const double MidX = (e.MaxX + e.MinX) / 2;
+            const double MidX = (envelope.MaxX + envelope.MinX) / 2;
 
-            e1.MinX = e.MinX;
-            e1.MinY = e.MinY;
+            e1.MinX = envelope.MinX;
+            e1.MinY = envelope.MinY;
             e1.MaxX = MidX;
-            e1.MaxY = e.MaxY;
+            e1.MaxY = envelope.MaxY;
 
             e2.MinX = MidX;
-            e2.MinY = e.MinY;
-            e2.MaxX = e.MaxX;
-            e2.MaxY = e.MaxY;
+            e2.MinY = envelope.MinY;
+            e2.MaxX = envelope.MaxX;
+            e2.MaxY = envelope.MaxY;
 
         }
 
@@ -392,11 +404,11 @@ void CoastlinePolygons::split_bbox(OGREnvelope e, polygon_vector_type&& v) {
             /* You might think re-computing the envelope of all those polygons
             again and again might take a lot of time, but I benchmarked it and
             it has no measurable impact. */
-            OGREnvelope e;
-            polygon->getEnvelope(&e);
+            OGREnvelope polygon_envelope;
+            polygon->getEnvelope(&polygon_envelope);
 
-            const bool e1_intersects_e = e1.Intersects(e);
-            const bool e2_intersects_e = e2.Intersects(e);
+            const bool e1_intersects_e = e1.Intersects(polygon_envelope);
+            const bool e2_intersects_e = e2.Intersects(polygon_envelope);
 
             if (e1_intersects_e && e2_intersects_e) {
                 v1.emplace_back(static_cast<OGRPolygon*>(polygon->clone()));
