@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2019 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -130,8 +130,8 @@ unsigned int CoastlineRingCollection::check_locations(bool output_missing) {
 }
 
 bool is_valid_polygon(const OGRGeometry* geometry) {
-    if (geometry && geometry->getGeometryType() == wkbPolygon) {
-        const auto polygon = static_cast<const OGRPolygon*>(geometry);
+    if (geometry && geometry->getGeometryType() == wkbPolygon && !geometry->IsEmpty()) {
+        const auto *const polygon = static_cast<const OGRPolygon*>(geometry);
         return (polygon->getExteriorRing()->getNumPoints() > 3) && (polygon->getNumInteriorRings() == 0) && geometry->IsValid();
     }
     return false;
