@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2019 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2021 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -33,12 +33,60 @@
 #define strcasecmp _stricmp
 #endif
 
+#include <osmium/io/pbf.hpp>
+
+static void print_help() {
+    std::cout << "Usage: osmcoastline [OPTIONS] OSMFILE\n"
+              << "\nOptions:\n"
+              << "  -h, --help                 - This help message\n"
+              << "  -c, --close-distance=DIST  - Distance between nodes under which open rings\n"
+              << "                               are closed (0 - disable closing of rings)\n"
+              << "  -b, --bbox-overlap=OVERLAP - Set overlap when splitting polygons\n"
+              << "  -i, --no-index             - Do not create spatial indexes in output db\n"
+              << "  -d, --debug                - Enable debugging output\n"
+              << "  -f, --overwrite            - Overwrite output file if it already exists\n"
+              << "  -g, --gdal-driver=DRIVER   - GDAL driver (SQLite or ESRI Shapefile)\n"
+              << "  -l, --output-lines         - Output coastlines as lines to database file\n"
+              << "  -m, --max-points=NUM       - Split lines/polygons with more than this many\n"
+              << "                               points (0 - disable splitting)\n"
+              << "  -o, --output-database=FILE - Database file for output\n"
+              << "  -p, --output-polygons=land|water|both|none\n"
+              << "                             - Which polygons to write out (default: land)\n"
+              << "  -r, --output-rings         - Output rings to database file\n"
+              << "  -s, --srs=EPSGCODE         - Set SRS (4326 for WGS84 (default) or 3857)\n"
+              << "  -S, --write-segments=FILE  - Write segments to given file\n"
+              << "  -v, --verbose              - Verbose output\n"
+              << "  -V, --version              - Show version and exit\n"
+              << "\n";
+}
+
+/**
+ * Get EPSG code from text. This method knows about a few common cases
+ * of specifying WGS84 or the "Web Mercator" SRS. More are currently
+ * not supported.
+ */
+static int get_epsg(const char* text) {
+    if (!strcasecmp(text, "WGS84") || !std::strcmp(text, "4326")) {
+        return 4326;
+    }
+    if (!std::strcmp(text, "3857")) {
+        return 3857;
+    }
+    if (!std::strcmp(text, "3785") || !std::strcmp(text, "900913")) {
+        std::cerr << "Please use code 3857 for the 'Web Mercator' projection!\n";
+        std::exit(return_code_cmdline);
+    }
+    std::cerr << "Unknown SRS '" << text << "'. Currently only 4326 (WGS84) and 3857 ('Web Mercator') are supported.\n";
+    std::exit(return_code_cmdline);
+}
+
 Options::Options(int argc, char* argv[]) {
     static struct option long_options[] = {
         {"bbox-overlap",    required_argument, nullptr, 'b'},
         {"close-distance",  required_argument, nullptr, 'c'},
         {"no-index",              no_argument, nullptr, 'i'},
         {"debug",                 no_argument, nullptr, 'd'},
+        {"gdal-driver",     required_argument, nullptr, 'g'},
         {"help",                  no_argument, nullptr, 'h'},
         {"output-lines",          no_argument, nullptr, 'l'},
         {"max-points",      required_argument, nullptr, 'm'},
@@ -54,7 +102,7 @@ Options::Options(int argc, char* argv[]) {
     };
 
     while (true) {
-        const int c = getopt_long(argc, argv, "b:c:idhlm:o:p:rfs:S:vV", long_options, nullptr);
+        const int c = getopt_long(argc, argv, "b:c:idg:hlm:o:p:rfs:S:vV", long_options, nullptr);
         if (c == -1) {
             break;
         }
@@ -79,6 +127,9 @@ Options::Options(int argc, char* argv[]) {
             case 'h':
                 print_help();
                 std::exit(return_code_ok);
+            case 'g':
+                driver = optarg;
+                break;
             case 'l':
                 output_lines = true;
                 break;
@@ -121,8 +172,13 @@ Options::Options(int argc, char* argv[]) {
                 verbose = true;
                 break;
             case 'V':
-                std::cout << "osmcoastline " << get_osmcoastline_long_version() << " / " << get_libosmium_version() << '\n'
-                          << "Copyright (C) 2012-2019  Jochen Topf <jochen@topf.org>\n"
+                std::cout << "osmcoastline " << get_osmcoastline_long_version() << "\n"
+                          << get_libosmium_version() << '\n'
+                          << "Supported PBF compression types:";
+                for (const auto& type : osmium::io::supported_pbf_compression_types()) {
+                    std::cout << " " << type;
+                }
+                std::cout << "\n\nCopyright (C) 2012-2021  Jochen Topf <jochen@topf.org>\n"
                           << "License: GNU GENERAL PUBLIC LICENSE Version 3 <https://gnu.org/licenses/gpl.html>.\n"
                           << "This is free software: you are free to change and redistribute it.\n"
                           << "There is NO WARRANTY, to the extent permitted by law.\n";
@@ -158,42 +214,3 @@ Options::Options(int argc, char* argv[]) {
     inputfile = argv[optind];
 }
 
-int Options::get_epsg(const char* text) {
-    if (!strcasecmp(text, "WGS84") || !std::strcmp(text, "4326")) {
-        return 4326;
-    }
-    if (!std::strcmp(text, "3857")) {
-        return 3857;
-    }
-    if (!std::strcmp(text, "3785") || !std::strcmp(text, "900913")) {
-        std::cerr << "Please use code 3857 for the 'Web Mercator' projection!\n";
-        std::exit(return_code_cmdline);
-    }
-    std::cerr << "Unknown SRS '" << text << "'. Currently only 4326 (WGS84) and 3857 ('Web Mercator') are supported.\n";
-    std::exit(return_code_cmdline);
-}
-
-void Options::print_help() const {
-    std::cout << "Usage: osmcoastline [OPTIONS] OSMFILE\n"
-              << "\nOptions:\n"
-              << "  -h, --help                 - This help message\n"
-              << "  -c, --close-distance=DIST  - Distance between nodes under which open rings\n"
-              << "                               are closed (0 - disable closing of rings)\n"
-              << "  -b, --bbox-overlap=OVERLAP - Set overlap when splitting polygons\n"
-              << "  -i, --no-index             - Do not create spatial indexes in output db\n"
-              << "  -d, --debug                - Enable debugging output\n"
-              << "  -f, --overwrite            - Overwrite output file if it already exists\n"
-              << "  -l, --output-lines         - Output coastlines as lines to database file\n"
-              << "  -m, --max-points=NUM       - Split lines/polygons with more than this many\n"
-              << "                               points (0 - disable splitting)\n"
-              << "  -o, --output-database=FILE - Spatialite database file for output\n"
-              << "  -p, --output-polygons=land|water|both|none\n"
-              << "                             - Which polygons to write out (default: land)\n"
-              << "  -r, --output-rings         - Output rings to database file\n"
-              << "  -s, --srs=EPSGCODE         - Set SRS (4326 for WGS84 (default) or 3857)\n"
-              << "  -S, --write-segments=FILE  - Write segments to given file\n"
-              << "  -v, --verbose              - Verbose output\n"
-              << "  -V, --version              - Show version and exit\n"
-              << "\n";
-}
-
